@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, 
- * Boston, MA 02111-1307, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __VINAGRE_WINDOW_H__
@@ -75,10 +73,13 @@ void		 vinagre_window_set_active_tab		(VinagreWindow         *window,
 
 GtkWidget	*vinagre_window_get_statusbar		(VinagreWindow         *window);
 GtkWidget	*vinagre_window_get_toolbar		(VinagreWindow         *window);
+GtkWidget	*vinagre_window_get_menubar		(VinagreWindow         *window);
 GtkWidget	*vinagre_window_get_fav_panel		(VinagreWindow         *window);
 GtkWidget	*vinagre_window_get_notebook		(VinagreWindow	       *window);
+GtkActionGroup	*vinagre_window_get_main_action		(VinagreWindow         *window);
+GtkActionGroup	*vinagre_window_get_sensitive_action	(VinagreWindow         *window);
 
-void		vinagre_window_update_favorites_list_menu (VinagreWindow       *window);
+void		vinagre_window_update_bookmarks_list_menu (VinagreWindow       *window);
 
 GtkUIManager	*vinagre_window_get_ui_manager		(VinagreWindow         *window);
 
@@ -87,6 +88,10 @@ gboolean	vinagre_window_is_fullscreen		(VinagreWindow         *window);
 void		vinagre_window_toggle_fullscreen	(VinagreWindow *window);
 void		vinagre_window_set_title		(VinagreWindow *window);
 
+void		_vinagre_window_add_machine_connected	(VinagreWindow *window);
+void		_vinagre_window_del_machine_connected	(VinagreWindow *window);
+
 G_END_DECLS
 
 #endif  /* __VINAGRE_WINDOW_H__  */
+/* vim: ts=8 */
